==> zio-aws-memorydb_2.12-5.17.163.1-sources.jar: zio/aws/memorydb/model/AuthenticationType.scala <==
package zio.aws.memorydb.model
import scala.jdk.CollectionConverters._
sealed trait AuthenticationType {
  def unwrap: software.amazon.awssdk.services.memorydb.model.AuthenticationType
}
object AuthenticationType {
  def wrap(
      value: software.amazon.awssdk.services.memorydb.model.AuthenticationType
  ): zio.aws.memorydb.model.AuthenticationType = value match {
    case software.amazon.awssdk.services.memorydb.model.AuthenticationType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.memorydb.model.AuthenticationType.PASSWORD =>
      val r = password
      r
    case software.amazon.awssdk.services.memorydb.model.AuthenticationType.NO_PASSWORD =>
      val r = `no-password`
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.memorydb.model.AuthenticationType {
    override def unwrap
        : software.amazon.awssdk.services.memorydb.model.AuthenticationType =
      software.amazon.awssdk.services.memorydb.model.AuthenticationType.UNKNOWN_TO_SDK_VERSION
  }
  case object password extends zio.aws.memorydb.model.AuthenticationType {
    override def unwrap
        : software.amazon.awssdk.services.memorydb.model.AuthenticationType =
      software.amazon.awssdk.services.memorydb.model.AuthenticationType.PASSWORD
  }
  case object `no-password` extends zio.aws.memorydb.model.AuthenticationType {
    override def unwrap
        : software.amazon.awssdk.services.memorydb.model.AuthenticationType =
      software.amazon.awssdk.services.memorydb.model.AuthenticationType.NO_PASSWORD
  }
}

==> zio-aws-memorydb_2.12-7.21.15.2-sources.jar: zio/aws/memorydb/model/AuthenticationType.scala <==
package zio.aws.memorydb.model
import scala.jdk.CollectionConverters._
sealed trait AuthenticationType {
  def unwrap: software.amazon.awssdk.services.memorydb.model.AuthenticationType
}
object AuthenticationType {
  def wrap(
      value: software.amazon.awssdk.services.memorydb.model.AuthenticationType
  ): zio.aws.memorydb.model.AuthenticationType = value match {
    case software.amazon.awssdk.services.memorydb.model.AuthenticationType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.memorydb.model.AuthenticationType.PASSWORD =>
      val r = password
      r
    case software.amazon.awssdk.services.memorydb.model.AuthenticationType.NO_PASSWORD =>
      val r = `no-password`
      r
    case software.amazon.awssdk.services.memorydb.model.AuthenticationType.IAM =>
      val r = iam
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.memorydb.model.AuthenticationType {
    override def unwrap
        : software.amazon.awssdk.services.memorydb.model.AuthenticationType =
      software.amazon.awssdk.services.memorydb.model.AuthenticationType.UNKNOWN_TO_SDK_VERSION
  }
  case object password extends zio.aws.memorydb.model.AuthenticationType {
    override def unwrap
        : software.amazon.awssdk.services.memorydb.model.AuthenticationType =
      software.amazon.awssdk.services.memorydb.model.AuthenticationType.PASSWORD
  }
  case object `no-password` extends zio.aws.memorydb.model.AuthenticationType {
    override def unwrap
        : software.amazon.awssdk.services.memorydb.model.AuthenticationType =
      software.amazon.awssdk.services.memorydb.model.AuthenticationType.NO_PASSWORD
  }
  case object iam extends zio.aws.memorydb.model.AuthenticationType {
    override def unwrap
        : software.amazon.awssdk.services.memorydb.model.AuthenticationType =
      software.amazon.awssdk.services.memorydb.model.AuthenticationType.IAM
  }
}
